@@ -17,7 +17,7 @@ use constant VALIDATE_IP       => eval 'require Data::Validate::IP;1';
 
 use constant DEBUG => $ENV{JSON_VALIDATOR_DEBUG} || 0;
 
-our $VERSION = '0.88';
+our $VERSION = '0.89';
 our @EXPORT_OK = 'validate_json';
 
 my $HTTP_SCHEME_RE = qr{^https?:};
@@ -535,7 +535,7 @@ sub _validate_type_number {
     push @errors, E $path, "$value $e maximum($schema->{maximum})";
   }
   if (my $d = $schema->{multipleOf}) {
-    unless (int($value / $d) == $value / $d) {
+    if (($value / $d) =~ /\.[^0]+$/) {
       push @errors, E $path, "Not multiple of $d.";
     }
   }
@@ -784,7 +784,7 @@ JSON::Validator - Validate data against a JSON schema
 
 =head1 VERSION
 
-0.88
+0.89
 
 =head1 SYNOPSIS
 
